@@ -1,6 +1,6 @@
 package Bundle::BioPerl;
 
-$VERSION = '2.1.9';
+$VERSION = '2.01';
 
 1;
 
@@ -8,11 +8,11 @@ __END__
 
 =head1 NAME
 
-Bundle::BioPerl - A bundle to install external CPAN modules used by BioPerl 1.5.2
+Bundle::BioPerl - A bundle to install external CPAN modules used by BioPerl
 
 =head1 SYNOPSIS
 
-
+  
 Perl one liner using CPAN.pm:
 
   perl -MCPAN -e 'install Bundle::BioPerl'
@@ -30,89 +30,40 @@ is allowed within the intstallation directory.
 
 =head1 CONTENTS
 
-    Algorithm::Munkres
+Bundle::LWP		- recommended, used for network access
 
-    Bio::Phylo
+File::Temp		- Already present in modern versions of perl
 
-    Class::AutoClass 1.01
+File::Spec		- Already present in modern versions of perl
 
-    Clone
+IO::Scalar		- optional, used only in Bio::Tools::Blast::Run::WebBlast.pm
 
-    Convert::Binary::C
+IO::String		- recommended, used by Bio::DB:WebDBSeqI
 
-    Data::Stag::Writer
-    
-    DB_File
+HTTP::Request::Common   - recommended, used for web access
 
-    DBD::mysql
+HTTP::Status            - recommended, used for web access
 
-    GD::SVG	- Optional, used to generate SVG output in Bio::Graphics
+LWP::UserAgent          - recommended, used for web access
 
-    GD 1.3	- Used only for drawing things within the Bio::Graphics modules
+URI::Escape             - recommended, used for web access
 
-    Graph::Directed	- This module is used for Ontology Engine implementation for the GO parser
+XML::Parser		- recommended for all bioperl releases after 0.6.2
 
-    GraphViz
+XML::Parser::PerlSAX	- recommended for all bioperl releases after 0.6.2
 
-    HTML::Entities
+XML::Writer		- recommended for all bioperl releases after 0.6.2
 
-    HTML::HeadParser
+XML::Node		- recommended for all bioperl releases after 0.6.2
 
-    HTML::Parser 3.0	- recommended, used to parse GDP page in Bio::DB::GDP
+XML::Twig		- recommended for all bioperl releases after 0.6.2
 
-    HTML::TableExtract
+SOAP::Lite		- Used for bibliographic queries & XEMBLService modules
 
-    HTTP::Request::Common - recommended, used for web access (part of libwww-perl)
+GD		- Used only for drawing things within the Bio::Graphics modules
 
-    IO::String
+Storable		- recommended for all bioperl releases after 0.7.2. Used for persistant storage of objects and local file caching
 
-    IO::Scalar
-
-    List::MoreUtils
-
-    LWP::UserAgent	- recommended, used for web access
-
-    PostScript::TextBlock
-
-    Scalar::Util
-
-    Set::Scalar
-
-    SOAP::Lite	- Used for bibliographic queries & XEMBLService modules
-
-    Sort::Naturally
-
-    Spreadsheet::ParseExcel
-
-    Storable	- recommended for all bioperl releases after 0.7.2. Used for persistant storage of objects and local file caching
-
-    SVG 2.26	- Optional, used to generate SVG output in Bio::Graphics
-
-    SVG::Graph 0.01	- Optional, used to generate SVG output in Bio::Graphics
-
-    Text::ParseWords	- Recommended, used in Bio::Graphics
-
-    XML::DOM
-
-    XML::DOM::XPath
-
-    XML::LibXML
-
-    XML::Parser
-
-    XML::Parser::PerlSAX	- recommended for all bioperl releases after 0.6.2
-
-    XML::SAX
-
-    XML::SAX::Writer
-
-    XML::Simple
-
-    XML::Twig	- recommended for all bioperl releases after 0.6.2
-
-    XML::Writer	- recommended for all bioperl releases after 0.6.2
-
-    YAML
 
 =head1 DESCRIPTION
 
@@ -123,15 +74,16 @@ contained within the standard Perl distribution. These external
 modules can be obtained from the Comprehensive Perl Archive 
 Network (CPAN) located at http://www.cpan.org. 
 
-NOTE: The latest release of this bundle includes all of the
+MARCH 2002 NOTE: The latest release of this bundle includes all of the
 external CPAN modules that are listed as dependencies of the
-official BioPerl 1.5.2 codebase release. 
+official BioPerl 1.0 codebase release. The only exceptions are the DBD::
+DBI:: modules which are really best off installed on their own if you
+have a need to load and query relational databases.
 
-The only exceptions are the DBD:: and DBI:: modules which are really 
-best off installed on their own if you have a need to load and 
-query relational. databases.
+A webpage listing all known dependencies is maintained at
+http://bioperl.org/Core/external.shtml
 
-These modules are not required - they greatly extend the functionality
+These modules are not required - they simply extend the functionality
 of bioperl in various ways. To get the best use of bioperl, particularly
 after the release of BioPerl 1.0 we recommend at least having the
 LWP:: network access and the XML:: related modules installed. 
@@ -156,7 +108,8 @@ outside of CPAN at http://sourceforge.net/projects/expat/.
 The C<install Bundle::BioPerl> process may need to be repeated
 several times to complete the full installation of all listed
 modules. Some external modules are complicated or may themselves
-have dependencies. 
+have dependencies. Wherever possible we attempt to track this
+online at http://bioperl.org/Core/external.shtml
 
 NOTE: This Bundle does not install BioPerl :) Just the additional
 modules that BioPerl code ocasionally makes use of. You will still
@@ -179,3 +132,7 @@ Chris Dagdigian E<lt>F<dag@sonsorol.org>E<gt>
 (Author only of this bundle, not any the modules it lists)
 
 =cut
+
+
+
+
